@@ -202,9 +202,11 @@ cond_indirect_diff <- function(output,
         names(mc_diff_ci) <- paste0(formatC(c(100 * (1 - level) / 2,
                                       100 * (1 - (1 - level) / 2)), 2,
                                       format = "f"), "%")
+        mc_diff_se <- stats::sd(mc_diff, na.rm = TRUE)
       } else {
         mc_diff <- NA
         mc_diff_ci <- c(NA, NA)
+        mc_diff_se <- NA
       }
     if (has_boot) {
         boot_diff <- boot_i_to - boot_i_from
@@ -220,20 +222,26 @@ cond_indirect_diff <- function(output,
                                       100 * (1 - (1 - level) / 2)), 2,
                                       format = "f"), "%")
         boot_diff_p <- est2p(boot_diff)
+        boot_diff_se <- stats::sd(boot_diff, na.rm = TRUE)
       } else {
         boot_diff <- NA
         boot_diff_ci <- c(NA, NA)
         boot_diff_p <- NA
+        boot_diff_se <- NA
       }
     wlevels <- attr(output, "wlevels")
     wlevels_from <- wlevels[from, , drop = FALSE]
     wlevels_to <- wlevels[to, , drop = FALSE]
     out_diff_ci <- c(NA, NA)
+    out_diff_se <- NA
     if (has_mc) out_diff_ci <- mc_diff_ci
     if (has_boot) out_diff_ci <- boot_diff_ci
+    if (has_mc) out_diff_se <- mc_diff_se
+    if (has_boot) out_diff_se <- boot_diff_se
     out <- list(index = effect_diff,
                 ci = out_diff_ci,
                 pvalue = boot_diff_p,
+                se = out_diff_se,
                 level = level,
                 from = wlevels_from,
                 to = wlevels_to,
@@ -292,6 +300,15 @@ cond_indirect_diff <- function(output,
 #' places to display for the *p*-value.
 #' Default is 3.
 #'
+#' @param se Logical. If `TRUE` and
+#' confidence intervals are available,
+#' the standard errors of the estimates
+#' are also printed. They are simply the
+#' standard deviations of the bootstrap
+#' estimates or Monte Carlo simulated
+#' values, depending on the method used
+#' to form the confidence intervals.
+#'
 #' @param ... Optional arguments.
 #' Ignored.
 #'
@@ -308,6 +325,7 @@ print.cond_indirect_diff <- function(x,
                                      digits = 3,
                                      pvalue = FALSE,
                                      pvalue_digits = 3,
+                                     se = FALSE,
                                      ...) {
     full_output_attr <- attr(x$output, "full_output")[[1]]
     print(x$output, digits = digits, annotation = FALSE, ...)
@@ -364,6 +382,13 @@ print.cond_indirect_diff <- function(x,
                                        digits = pvalue_digits,
                                        format = "f")
           }
+        if ((!identical(NA, x$boot_diff) || !identical(NA, x$mc_diff)) &&
+            !is.na(x$se) &&
+            se) {
+            index_df$SE <- formatC(x$se,
+                                   digits = digits,
+                                   format = "f")
+          }
       }
     if (!is.null(x_type)) {
         rownames(index_df) <- "Index"
@@ -388,6 +413,11 @@ print.cond_indirect_diff <- function(x,
             pvalue) {
             cat(" - P-value is asymmetric bootstrap p-value.\n", sep = "")
           }
+        if ((!identical(NA, x$boot_diff) || !identical(NA, x$mc_diff)) &&
+            !is.na(x$se) &&
+            se) {
+            cat(" - [SE]: Standard error.\n", sep = "")
+          }
       }
     if (full_output_attr$standardized_x) {
         cat(" - ", full_output_attr$x, " standardized.\n", sep = "")
